summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KLineEdit.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KLineEdit.java')
-rw-r--r--kdejava/koala/org/kde/koala/KLineEdit.java50
1 files changed, 25 insertions, 25 deletions
diff --git a/kdejava/koala/org/kde/koala/KLineEdit.java b/kdejava/koala/org/kde/koala/KLineEdit.java
index 25b38f18..e9691923 100644
--- a/kdejava/koala/org/kde/koala/KLineEdit.java
+++ b/kdejava/koala/org/kde/koala/KLineEdit.java
@@ -38,16 +38,16 @@ import org.kde.qt.TQLineEdit;
appropriate.
This widget by default creates a completion object when you invoke
the completionObject( boolean ) member function for the first time or
- use setCompletionObject( KCompletion, boolean ) to assign your own
+ use setCompletionObject( TDECompletion, boolean ) to assign your own
completion object. Additionally, to make this widget more functional,
KLineEdit will by default handle the text rotation and completion
events internally when a completion object is created through either one
of the methods mentioned above. If you do not need this functionality,
- simply use KCompletionBase.setHandleSignals( boolean ) or set the
+ simply use TDECompletionBase.setHandleSignals( boolean ) or set the
booleanean parameter in the above functions to false.
The default key-bindings for completion and rotation is determined
from the global settings in TDEStdAccel. These values, however,
- can be overridden locally by invoking KCompletionBase.setKeyBinding().
+ can be overridden locally by invoking TDECompletionBase.setKeyBinding().
The values can easily be reverted back to the default setting, by simply
calling useGlobalSettings(). An alternate method would be to default
individual key-bindings by using setKeyBinding() with the default
@@ -55,7 +55,7 @@ import org.kde.qt.TQLineEdit;
If <code>EchoMode</code> for this widget is set to something other than <code>TQLineEdit</code>.Normal,
the completion mode will always be defaulted to TDEGlobalSettings.CompletionNone.
This is done purposefully to guard against protected entries such as passwords being
- cached in KCompletion's list. Hence, if the <code>EchoMode</code> is not TQLineEdit.Normal, the
+ cached in TDECompletion's list. Hence, if the <code>EchoMode</code> is not TQLineEdit.Normal, the
completion mode is automatically disabled.
A read-only KLineEdit will have the same background color as a
disabled KLineEdit, but its foreground color will be the one used
@@ -66,7 +66,7 @@ import org.kde.qt.TQLineEdit;
To enable the basic completion feature :
<pre>
KLineEdit edit = new KLineEdit( this, "mywidget" );
- KCompletion comp = edit.completionObject();
+ TDECompletion comp = edit.completionObject();
// Connect to the return pressed signal - optional
connect(edit,SIGNAL("returnPressed(String)"),comp,SLOT("addItem(String)"));
</pre>
@@ -90,7 +90,7 @@ import org.kde.qt.TQLineEdit;
// Tell the widget to not handle completion and iteration automatically.
edit.setHandleSignals( false );
// Set your own key-bindings for a text completion mode.
- edit.setKeyBinding( KCompletionBase.TextCompletion, Qt.End );
+ edit.setKeyBinding( TDECompletionBase.TextCompletion, Qt.End );
// Hide the context (popup) menu
edit.setContextMenuEnabled( false );
// Temporarily disable signal (both completion & iteration) emitions
@@ -104,7 +104,7 @@ import org.kde.qt.TQLineEdit;
@short An enhanced TQLineEdit widget for inputting text.
*/
-public class KLineEdit extends TQLineEdit implements KCompletionBaseInterface {
+public class KLineEdit extends TQLineEdit implements TDECompletionBaseInterface {
protected KLineEdit(Class dummy){super((Class) null);}
public native TQMetaObject metaObject();
public native String className();
@@ -154,11 +154,11 @@ public class KLineEdit extends TQLineEdit implements KCompletionBaseInterface {
*/
public native void setURL(KURL url);
/**
- Re-implemented from KCompletionBase for internal reasons.
+ Re-implemented from TDECompletionBase for internal reasons.
This function is re-implemented in order to make sure that
the EchoMode is acceptable before we set the completion mode.
- See KCompletionBase.setCompletionMode
- @short Re-implemented from KCompletionBase for internal reasons.
+ See TDECompletionBase.setCompletionMode
+ @short Re-implemented from TDECompletionBase for internal reasons.
*/
public native void setCompletionMode(int mode);
/**
@@ -225,14 +225,14 @@ public class KLineEdit extends TQLineEdit implements KCompletionBaseInterface {
@short
*/
- public native KCompletionBox completionBox(boolean create);
- public native KCompletionBox completionBox();
+ public native TDECompletionBox completionBox(boolean create);
+ public native TDECompletionBox completionBox();
/**
Reimplemented for internal reasons, the API is not affected.
@short Reimplemented for internal reasons, the API is not affected.
*/
- public native void setCompletionObject(KCompletion arg1, boolean hsig);
- public native void setCompletionObject(KCompletion arg1);
+ public native void setCompletionObject(TDECompletion arg1, boolean hsig);
+ public native void setCompletionObject(TDECompletion arg1);
/**
Reimplemented for internal reasons, the API is not affected.
@short Reimplemented for internal reasons, the API is not affected.
@@ -266,10 +266,10 @@ public class KLineEdit extends TQLineEdit implements KCompletionBaseInterface {
Set the completion-box to be used in completion mode
TDEGlobalSettings.CompletionPopup.
This will do nothing if a completion-box already exists.
- @param box The KCompletionBox to set
+ @param box The TDECompletionBox to set
@short Set the completion-box to be used in completion mode TDEGlobalSettings.CompletionPopup.
*/
- public native void setCompletionBox(KCompletionBox box);
+ public native void setCompletionBox(TDECompletionBox box);
/**
Re-implemented for internal reasons. API not changed.
@short Re-implemented for internal reasons.
@@ -286,8 +286,8 @@ public class KLineEdit extends TQLineEdit implements KCompletionBaseInterface {
*/
public native void rotateText(int type);
/**
- See KCompletionBase.setCompletedText.
- @short See KCompletionBase.setCompletedText.
+ See TDECompletionBase.setCompletedText.
+ @short See TDECompletionBase.setCompletedText.
*/
public native void setCompletedText(String arg1);
/**
@@ -425,8 +425,8 @@ public class KLineEdit extends TQLineEdit implements KCompletionBaseInterface {
@short Returns a pointer to the current completion object.
*/
- public native KCompletion completionObject(boolean hsig);
- public native KCompletion completionObject();
+ public native TDECompletion completionObject(boolean hsig);
+ public native TDECompletion completionObject();
/**
Enables this object to handle completion and rotation
events internally.
@@ -569,7 +569,7 @@ public class KLineEdit extends TQLineEdit implements KCompletionBaseInterface {
/**
Returns a pointer to the completion object.
This method is only different from completionObject()
- in that it does not create a new KCompletion object even if
+ in that it does not create a new TDECompletion object even if
the internal pointer is <code>NULL.</code> Use this method to get the
pointer to a completion object when inheriting so that you
won't inadvertently create it!!
@@ -577,7 +577,7 @@ public class KLineEdit extends TQLineEdit implements KCompletionBaseInterface {
@short Returns a pointer to the completion object.
*/
- public native KCompletion compObj();
+ public native TDECompletion compObj();
/**
Returns a key-binding map.
This method is the same as getKeyBinding() except it
@@ -586,14 +586,14 @@ public class KLineEdit extends TQLineEdit implements KCompletionBaseInterface {
@short Returns a key-binding map.
*/
// KCompletionBase::KeyBindingMap getKeyBindings(); >>>> NOT CONVERTED
/**
Sets or removes the delegation object. If a delegation object is
set, all function calls will be forwarded to the delegation object.
@param delegate the delegation object, or 0 to remove it
@short Sets or removes the delegation object.
*/
- protected native void setDelegate(KCompletionBaseInterface delegate);
+ protected native void setDelegate(TDECompletionBaseInterface delegate);
/**
Returns the delegation object.
@return the delegation object, or 0 if there is none
@@ -601,5 +601,5 @@ public class KLineEdit extends TQLineEdit implements KCompletionBaseInterface {
@short Returns the delegation object.
@see #setDelegate
*/
- protected native KCompletionBaseInterface delegate();
+ protected native TDECompletionBaseInterface delegate();
}
@@ -586,14 +586,14 @@ public class KLineEdit extends TQLineEdit implements KCompletionBaseInterface {
*/
- // KCompletionBase::KeyBindingMap getKeyBindings(); >>>> NOT CONVERTED
+ // TDECompletionBase::KeyBindingMap getKeyBindings(); >>>> NOT CONVERTED
/**
Sets or removes the delegation object. If a delegation object is